import json
from os import path
from munch import Munch

def loadFile(file):
    if not file or not path.exists(file):
        return None

    with open(file, 'r') as f:
        return f.read() 

def jsonFileToDct(file):
    if not file or not path.exists(file):
        return None

    with open(file, 'r') as f:
        return json.load(f)  
    
def jsonFileToObj(file):
    dct = jsonFileToDct(file)  
    
    return Munch.fromDict(dct) if dct else None    

def dctToFile(dct, file):
    with open(file, 'w') as f:     
        f.write(json.dumps(dct, sort_keys=False, indent=4)) 

def fileSize(file):
    if not file or not path.exists(file):
        return -1
    return path.getsize(file)     



class bcolors:
    GRAY = '\033[90m'
    RED = '\033[91m'
    GREEN = '\033[92m'
    YELLOW = '\033[93m'
    BLUE = '\033[94m'
    PINK = '\033[95m'
    CYAN = '\033[96m'
    WHITE = '\033[97m'    
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'
   


def print_pink(msg):
    print(f"{bcolors.PINK}{msg}{bcolors.ENDC}")

def print_blue(msg):
    print(f"{bcolors.BLUE}{msg}{bcolors.ENDC}")

def print_cyan(msg):
    print(f"{bcolors.CYAN}{msg}{bcolors.ENDC}")

def print_green(msg):
    print(f"{bcolors.GREEN}{msg}{bcolors.ENDC}")

def print_yellow(msg):
    print(f"{bcolors.YELLOW}{msg}{bcolors.ENDC}")

def print_red(msg):
    print(f"{bcolors.RED}{msg}{bcolors.ENDC}")    

def print_pinkb(msg):
    print(f"{bcolors.PINK}{bcolors.BOLD}{msg}{bcolors.ENDC}")

def print_blueb(msg):
    print(f"{bcolors.BLUE}{bcolors.BOLD}{msg}{bcolors.ENDC}")

def print_cyanb(msg):
    print(f"{bcolors.CYAN}{bcolors.BOLD}{msg}{bcolors.ENDC}")

def print_greenb(msg):
    print(f"{bcolors.GREEN}{bcolors.BOLD}{msg}{bcolors.ENDC}")

def print_yellowb(msg):
    print(f"{bcolors.YELLOW}{bcolors.BOLD}{msg}{bcolors.ENDC}")

def print_redb(msg):
    print(f"{bcolors.RED}{bcolors.BOLD}{msg}{bcolors.ENDC}")  

def helloWorld():
    print("Hello World!")
    
